<?php
/**
 * Receipt Rendering Functions and Filters
 *
 * @package  WooCommerce Mix and Match Products/Receipts
 * @since    2.7.4
 * @version  2.7.4
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * WC_MNM_Receipt_Rendering Class.
 *
 * Functions and filters for Mix and Match customizer options.
 */
class WC_MNM_Receipt_Rendering {

	/**
	 * Attach hooks and filters
	 */
	public static function init() {
		add_filter( 'woocommerce_printable_order_receipt_css', array( __CLASS__, 'order_receipt_css' ), 10 );
		add_filter( 'woocommerce_printable_order_receipt_line_item_display_data', array( __CLASS__, 'line_item_display_data' ), 10, 2 );
	}

	/**
	 * Style the indent arrow for Mix and Match container's child items products.
	 * 
	 * @param string $css The style rules for the receipt engine
	 * @return string The updated css rules
	 */
	public static function order_receipt_css( $css ) {

		$css .= "
		.mnm_table_item .indent-arrow { display: inline-block; transform: scaleX(-1); padding-right: 1em; padding-left: .25em; }
		";
		return $css;
	}

	/**
	 * Modify the receipt output for Mix and Match container's child items products.
	 * 
	 * @param array $line_item_display_data Data to use to generate the HTML table row to be rendered for the line item.
	 * @param array $line_item_data The relevant data for the line item for which the HTML table row is being generated.
	 * @return array The actual data to use to generate the HTML for the line item. 
	 */
	public static function line_item_display_data( $line_item_display_data, $line_item_data ) {

		if ( isset( $line_item_data['item'] ) && wc_mnm_maybe_is_child_order_item( $line_item_data['item'] ) ) {

			$line_item_display_data['tr_attributes']['class'] = trim(($data['tr_attributes']['class'] ?? '') . ' mnm_table_item' );

			// Add an indent arrow to the first td element.
			$inner_html = preg_replace('/(<td>)/', '$1<span class="indent-arrow">&crarr;</span>',$line_item_display_data['inner_html'], 1);
			$line_item_display_data['inner_html'] = $inner_html;
		}
		return $line_item_display_data;
	}


} // End class.
