<?php
/**
 * Singleton trait to handle getting instances of classes.
 * 
 * @since 2.7.0
 * @version 2.7.0
 */
trait WC_MNM_Singleton {
    /**
	 * Hold the single instance.
	 */
    protected static $instance;

    /**
	 * Get single instance.
	 */
    final public static function get_instance() {
        return isset(static::$instance)
            ? static::$instance
            : static::$instance = new static;
    }
    /**
	 * Class constructor
	 */
    final public function __construct() {
        $this->init();
    }

    /**
	 * Auto run init on class generation.
	 */
    protected function init() {}
    /**
	 * Cloning is forbidden.
	 */
	final public function __clone() {
		_doing_it_wrong( __FUNCTION__, esc_html__( 'Cloning this object is forbidden.', 'woocommerce-mix-and-match-products' ) );
	}

	/**
	 * Unserializing instances of this class is forbidden.
	 */
	final public function __wakeup() {
		_doing_it_wrong( __FUNCTION__, esc_html__( 'Unserializing instances of this class is forbidden.', 'woocommerce-mix-and-match-products' ) );
	}
}